import CronCore from '@vue-js-cron/core';
import { resolveComponent, openBlock, createBlock, createSlots, withCtx, createTextVNode, toDisplayString, createVNode, createElementBlock, Fragment, renderList, createCommentVNode, withModifiers, mergeProps, toHandlers } from 'vue';

var script$1 = {
  inheritAttrs: false,
  name: 'CustomSelect',
  props: {
    multiple: {
      type: Boolean,
      default: false
    },
    modelValue: {
      type: [String, Array, Object],
      default (props) {
        return props.multiple ? [] : null
      }
    },
    items: {
      type: Array,
      default: () => []
    },
    returnObject: {
      type: Boolean,
      default: false
    },
    itemText: {
      type: String,
      default: 'text'
    },
    itemValue: {
      type: String,
      default: 'value'
    },
    cols: {
      type: Number,
      default: 1
    },
    width: {
      type: String,
      default: 'unset'
    },
    variant: {
      type: String,
      default: 'elevated'
    },
    density: {
      type: String,
      default: 'default'
    },
    selection: {
      type: String,
      default: ''
    },
    closeOnContentClick: {
      type: Boolean,
      default: true
    },
    clearable: {
      type: Boolean,
      default: false
    }
  },
  emits: ['update:model-value'],
  data () {
    return {
      menu: false
    }
  },
  computed: {
    listStyle () {
      return {
        display: (this.menu) ? 'inline-block' : 'none',
        minWidth: '5em',
        width: this.width
      }
    },
    listItemStyle () {
      return {
        width: 100 / this.cols + '%'
      }
    },
    _value () {
      return (this.multiple) ? this.modelValue : [this.modelValue]
    },
    selectedItems () {
      return this.items.filter((item) => {
        for (const value of this._value) {
          if (this.returnObject) {
            if (value === item) return true
          } else {
            if (value === item[this.itemValue]) return true
          }
        }
        return false
      })
    },
    selectedStr () {
      return this.selectedItems.map((item) => item[this.itemText]).join(',')
    },
    rows () {
      return Array.isArray(this.items) ? Math.ceil(this.items.length / this.cols) : 0
    },
    itemRows () {
      return Array.from(Array(this.rows), (_, i) => {
        return Array.from(Array(this.cols), (_, j) => {
          return this.items[this.cols * i + j]
        })
      })
    }
  },
  methods: {
    menuEvtListener (evt) {
      this.menu = false;
      document.removeEventListener('click', this.menuEvtListener);
    },
    toggleMenu () {
      this.menu = !this.menu;

      if (this.menu) {
        setTimeout(() => {
          document.addEventListener('click', this.menuEvtListener);
        }, 1);
      } else {
        document.removeEventListener('click', this.menuEvtListener);
      }
    },
    select (item) {
      if (this.multiple) {
        const value = this.selectedItems.slice();
        const i = this.selectedItems.indexOf(item);
        // deselect
        if (i >= 0) {
          value.splice(i, 1);
        } else { // select
          value.push(item);
        }
        this.$emit('update:model-value', (this.returnObject) ? value : value.map((item) => item[this.itemValue]));
      } else {
        this.$emit('update:model-value', (this.returnObject) ? item : item[this.itemValue]);
      }
    },
    clear () {
      this.$emit('update:model-value', this.multiple ? [] : null);
    }
  }
};

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_v_icon = resolveComponent("v-icon");
  const _component_v_list_item = resolveComponent("v-list-item");
  const _component_v_col = resolveComponent("v-col");
  const _component_v_row = resolveComponent("v-row");
  const _component_v_list = resolveComponent("v-list");
  const _component_v_menu = resolveComponent("v-menu");
  const _component_v_chip = resolveComponent("v-chip");

  return (openBlock(), createBlock(_component_v_chip, {
        key: 0,
        density: $props.density,
        variant: $props.variant
      }, createSlots({
        default: withCtx(() => [
          createTextVNode(" " + toDisplayString($props.selection ? $props.selection : $options.selectedStr) + " ", 1 /* TEXT */),
          createVNode(_component_v_menu, {
            activator: "parent",
            "close-on-content-click": $props.closeOnContentClick
          }, {
            default: withCtx(() => [
              createVNode(_component_v_list, { class: "pa-0 ma-0" }, {
                default: withCtx(() => [
                  (openBlock(true), createElementBlock(Fragment, null, renderList($options.itemRows, (itemRow, index) => {
                    return (openBlock(), createBlock(_component_v_row, {
                      key: index,
                      "no-gutters": ""
                    }, {
                      default: withCtx(() => [
                        (openBlock(true), createElementBlock(Fragment, null, renderList(itemRow, (item, index) => {
                          return (openBlock(), createBlock(_component_v_col, { key: index }, {
                            default: withCtx(() => [
                              item
                                ? (openBlock(), createBlock(_component_v_list_item, {
                                    key: 0,
                                    onClick: $event => ($options.select(item)),
                                    active: $options.selectedItems.includes(item)
                                  }, {
                                    default: withCtx(() => [
                                      createTextVNode(toDisplayString(item[$props.itemText]), 1 /* TEXT */)
                                    ]),
                                    _: 2 /* DYNAMIC */
                                  }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["onClick", "active"]))
                                : createCommentVNode("v-if", true)
                            ]),
                            _: 2 /* DYNAMIC */
                          }, 1024 /* DYNAMIC_SLOTS */))
                        }), 128 /* KEYED_FRAGMENT */))
                      ]),
                      _: 2 /* DYNAMIC */
                    }, 1024 /* DYNAMIC_SLOTS */))
                  }), 128 /* KEYED_FRAGMENT */))
                ]),
                _: 1 /* STABLE */
              })
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["close-on-content-click"])
        ]),
        _: 2 /* DYNAMIC */
      }, [
        ($props.clearable)
          ? {
              name: "append",
              fn: withCtx(() => [
                ($options.selectedItems.length > 0)
                  ? (openBlock(), createBlock(_component_v_icon, {
                      key: 0,
                      size: "small",
                      icon: "mdi-close",
                      onClick: _cache[0] || (_cache[0] = withModifiers($event => ($options.clear()), ["stop"]))
                    }))
                  : createCommentVNode("v-if", true)
              ])
            }
          : undefined
      ]), 1032 /* PROPS, DYNAMIC_SLOTS */, ["density", "variant"]))
    
}

script$1.render = render$1;
script$1.__file = "src/components/CustomSelect.vue";

var script = {
  name: 'VueCronEditor',
  components: {
    CronCore: CronCore.component,
    CustomSelect: script$1
  },
  props: {
    variant: {
      type: String,
      default: 'elevated'
    },
    density: {
      type: String,
      default: 'default'
    },
    cols: {
      type: Function,
      default: (fieldId) => {
        if (fieldId === 'minute') return 5
        else if (fieldId === 'hour') return 4
        else if (fieldId === 'day') return 4
        else return 1
      }
    }
  },
  emits: ['update:model-value', 'error']
};

function render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_v_col = resolveComponent("v-col");
  const _component_custom_select = resolveComponent("custom-select");
  const _component_v_row = resolveComponent("v-row");
  const _component_CronCore = resolveComponent("CronCore");

  return (openBlock(), createBlock(_component_CronCore, mergeProps(_ctx.$attrs, {
    "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => (_ctx.$emit('update:model-value', $event))),
    onError: _cache[1] || (_cache[1] = $event => (_ctx.$emit('error', $event)))
  }), {
    default: withCtx(({fields, period}) => [
      createVNode(_component_v_row, {
        align: "baseline",
        dense: ""
      }, {
        default: withCtx(() => [
          (period.prefix)
            ? (openBlock(), createBlock(_component_v_col, {
                key: 0,
                class: "flex-grow-0"
              }, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(period.prefix), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1024 /* DYNAMIC_SLOTS */))
            : createCommentVNode("v-if", true),
          createVNode(_component_v_col, { cols: "auto" }, {
            default: withCtx(() => [
              createVNode(_component_custom_select, mergeProps(period.attrs, {
                items: period.items
              }, toHandlers(period.events), {
                "item-value": "id",
                density: $props.density,
                variant: $props.variant
              }), null, 16 /* FULL_PROPS */, ["items", "density", "variant"])
            ]),
            _: 2 /* DYNAMIC */
          }, 1024 /* DYNAMIC_SLOTS */),
          (period.suffix)
            ? (openBlock(), createBlock(_component_v_col, {
                key: 1,
                class: "flex-grow-0"
              }, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(period.suffix), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1024 /* DYNAMIC_SLOTS */))
            : createCommentVNode("v-if", true),
          (openBlock(true), createElementBlock(Fragment, null, renderList(fields, (f) => {
            return (openBlock(), createElementBlock(Fragment, {
              key: f.id
            }, [
              (f.prefix)
                ? (openBlock(), createBlock(_component_v_col, {
                    key: 0,
                    class: "flex-grow-0"
                  }, {
                    default: withCtx(() => [
                      createTextVNode(toDisplayString(f.prefix), 1 /* TEXT */)
                    ]),
                    _: 2 /* DYNAMIC */
                  }, 1024 /* DYNAMIC_SLOTS */))
                : createCommentVNode("v-if", true),
              createVNode(_component_v_col, { cols: "auto" }, {
                default: withCtx(() => [
                  createVNode(_component_custom_select, mergeProps(f.attrs, toHandlers(f.events), {
                    selection: f.selectedStr,
                    cols: $props.cols(f.id),
                    items: f.items,
                    multiple: "",
                    density: $props.density,
                    variant: $props.variant,
                    "close-on-content-click": false,
                    clearable: ""
                  }), null, 16 /* FULL_PROPS */, ["selection", "cols", "items", "density", "variant"])
                ]),
                _: 2 /* DYNAMIC */
              }, 1024 /* DYNAMIC_SLOTS */),
              (f.suffix)
                ? (openBlock(), createBlock(_component_v_col, {
                    key: 1,
                    class: "flex-grow-0"
                  }, {
                    default: withCtx(() => [
                      createTextVNode(toDisplayString(f.suffix), 1 /* TEXT */)
                    ]),
                    _: 2 /* DYNAMIC */
                  }, 1024 /* DYNAMIC_SLOTS */))
                : createCommentVNode("v-if", true)
            ], 64 /* STABLE_FRAGMENT */))
          }), 128 /* KEYED_FRAGMENT */))
        ]),
        _: 2 /* DYNAMIC */
      }, 1024 /* DYNAMIC_SLOTS */)
    ]),
    _: 1 /* STABLE */
  }, 16 /* FULL_PROPS */))
}

script.render = render;
script.__file = "src/CronEditor.vue";

// Import vue component

// Declare install function executed by Vue.use()
function install (Vue) {
  if (install.installed) return
  install.installed = true;
  Vue.component('CronVuetify', script);
}

// Create module definition for Vue.use()
const plugin = {
  install,
  component: script,
  util: CronCore.util
};

export { plugin as default, install };
